# ---------------------------------------------------------------------------
# This python script is an ArcGIS script that can only be run on a computer
# with and ArcGIS licence and version 2.4.1 python.
# This script is designed to read in .asc files and deliever rasters with
# projection (GDA94z50) held in a file geodatabase (called raster)
# written by Kristy Van Putten and Ross Wilson
# ---------------------------------------------------------------------------

# Import system modules
import sys, string, os, arcgisscripting, glob, os.path

# Create the Geoprocessor object
gp = arcgisscripting.create()

# Check out any necessary licenses
gp.CheckOutExtension("spatial")

# Load required toolboxes...
gp.AddToolbox("C:/Program Files/ArcGIS/ArcToolbox/Toolboxes/Spatial Analyst Tools.tbx")
gp.AddToolbox("C:/Program Files/ArcGIS/ArcToolbox/Toolboxes/Conversion Tools.tbx")
gp.AddToolbox("C:/Program Files/ArcGIS/ArcToolbox/Toolboxes/Data Management Tools.tbx")
gp.overwriteoutput = 1

scenario_dir = "\\\\nas2\\gemd\\georisk_models\\inundation\\data\\thailand\\patong_tsunami_scenario\\"
output_dir="anuga\\outputs\\"


time_dir1 = '20081113_153848_run_final_0_kvanputt'

time_dirs = [time_dir1]

for time_dir in time_dirs:

    # Local variables...
    folder = scenario_dir + output_dir + time_dir + '\\'
    raster_gbd = folder + 'raster.gdb'
   # land = scenario_dir + "map_work\\Patong.gdb\\poly_all_cut"
    
    # Process: Create File GDB...
    gp.CreateFileGDB_management(folder, "raster")

    gp.Workspace = raster_gbd

    #print gp.Workspace
    
    #replication dictionary
    replicate = (('patong', ''),('_', '')) #,('depth','_dep_'),
                 #('speed', '_spe_'), ('elevation', '_ele_'), ('stage','_sta_'))

    generate_filename = []
    input_ascii = glob.glob(folder + '*.asc')

    for infile in input_ascii:
        output_DEM = os.path.basename(infile)[:-4]
        for (key, rep) in replicate:
            output_DEM = output_DEM.replace(key,rep)
        output_DEM = output_DEM[:10]
        if output_DEM in generate_filename:
            print 'Output_DEM filename (%s) already in use' % output_DEM
            sys.exit(10)
        generate_filename.append(output_DEM)
        print 'Output DEM ',output_DEM
        output_extract = output_DEM + 'E'
        print 'Output Extract ',output_extract
        
        print 'Process: ASCII to Raster'
        gp.ASCIIToRaster_conversion(infile, output_DEM, "FLOAT")

        print 'Process: Define Projection' 
        gp.DefineProjection_management(output_DEM, "PROJCS['WGS_1984_UTM_Zone_47N',GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984'"
                                                   ",SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0]"
                                                   ",UNIT['Degree',0.0174532925199433]],PROJECTION['Transverse_Mercator']"
                                                   ",PARAMETER['False_Easting',500000.0],PARAMETER['False_Northing',0.0]"
                                                   ",PARAMETER['Central_Meridian',99.0],PARAMETER['Scale_Factor',0.9996]"
                                                   ",PARAMETER['Latitude_Of_Origin',0.0],UNIT['Meter',1.0]]")



##        print 'Process: Extract by Mask'
##        gp.ExtractByMask_sa(output_DEM, land, output_extract)


